==> makumba-0_7-src.zip: makumba/classes/org/makumba/providers/query/oql/OQLAST.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: OQLAST.java 2256 2008-04-20 14:33:55Z manuel_gay $
//  $Name$
/////////////////////////////////////

package org.makumba.providers.query.oql;

import org.makumba.commons.NameResolver;
import antlr.CommonAST;

public class OQLAST extends CommonAST
{
  /**
	 * 
	 */
	private static final long serialVersionUID = 1L;

public OQLAST(){};
  public OQLAST(antlr.Token t) { super(t); }
  public String writeInSQLQuery(NameResolver nr){return getText(); }

  /* used in expressions */
  Object makumbaType;
  
  Object extraInfo;

  AnalysisTree tree;

  public Object getMakumbaType() throws antlr.RecognitionException
  {
    if(tree!=null)
      return tree.getMakumbaType();
    else
      return makumbaType;
  }
}

==> makumba-0_8_1_3-src.zip: makumba/classes/org/makumba/providers/query/oql/OQLAST.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: OQLAST.java 2777 2008-07-07 15:38:42Z rosso_nero $
//  $Name$
/////////////////////////////////////

package org.makumba.providers.query.oql;

import org.makumba.commons.NameResolver;

import antlr.CommonAST;

public class OQLAST extends CommonAST {
    private static final long serialVersionUID = 1L;

    public OQLAST() {
    }

    public OQLAST(antlr.Token t) {
        super(t);
    }

    public String writeInSQLQuery(NameResolver nr) {
        return getText();
    }

    /* used in expressions */
    Object makumbaType;

    Object extraInfo;

    AnalysisTree tree;

    public Object getMakumbaType() throws antlr.RecognitionException {
        if (tree != null) {
            return tree.getMakumbaType();
        } else {
            return makumbaType;
        }
    }
}
